@@ -135,14 +135,15 @@ kpAbstractImageSelection::~kpAbstractImageSelection ()
 // public virtual [base kpAbstractSelection]
 bool kpAbstractImageSelection::readFromStream (QDataStream &stream)
 {
-    if (!kpAbstractSelection::readFromStream (stream ))
+    if (!kpAbstractSelection::readFromStream (stream )) {
         return false;
+    }
 
     QImage qimage;
     stream >> qimage;
 #if DEBUG_KP_SELECTION && 1
     qCDebug(kpLogLayers) << "\timage: w=" << qimage.width () << " h=" << qimage.height ()
-               << " depth=" << qimage.depth () << endl;
+               << " depth=" << qimage.depth ();
 #endif
 
     if (!qimage.isNull ())
@@ -159,8 +160,9 @@ bool kpAbstractImageSelection::readFromStream (QDataStream &stream)
     }
     // (was just a selection border in the clipboard, even though KolourPaint's
     //  GUI doesn't allow you to copy such a thing into the clipboard)
-    else
+    else {
         d->baseImage = kpImage ();
+    }
 
     // TODO: Reset transparency mask?
     // TODO: Concrete subclass need to emit changed()?
@@ -276,8 +278,9 @@ kpImage kpAbstractImageSelection::givenImageMaskedByShape (const kpImage &image)
 #endif
     Q_ASSERT (image.width () == width () && image.height () == height ());
 
-    if (isRectangular ())
+    if (isRectangular ()) {
         return image;
+    }
 
     const QRegion mRegion = shapeRegion ().translated (-topLeft ());
 
@@ -313,8 +316,9 @@ bool kpAbstractImageSelection::hasContent () const
 // public virtual [kpAbstractSelection]
 void kpAbstractImageSelection::deleteContent ()
 {
-    if (!hasContent ())
+    if (!hasContent ()) {
         return;
+    }
 
     setBaseImage (kpImage ());
 }
@@ -359,8 +363,9 @@ bool kpAbstractImageSelection::setTransparency (
         const kpImageSelectionTransparency &transparency,
         bool checkTransparentPixmapChanged)
 {
-    if (d->transparency == transparency)
+    if (d->transparency == transparency) {
         return false;
+    }
 
     d->transparency = transparency;
 
@@ -403,14 +408,16 @@ bool kpAbstractImageSelection::setTransparency (
                 }
             }
 
-            if (!changed)
+            if (!changed) {
                 haveChanged = false;
+            }
         }
     }
 
 
-    if (haveChanged)
+    if (haveChanged) {
         emit changed (boundingRect ());
+    }
 
     return haveChanged;
 }
@@ -523,7 +530,7 @@ void kpAbstractImageSelection::flip (bool horiz, bool vert)
 {
 #if DEBUG_KP_SELECTION && 1
     qCDebug(kpLogLayers) << "kpAbstractImageSelection::flip(horiz=" << horiz
-               << ",vert=" << vert << ")" << endl;
+               << ",vert=" << vert << ")";
 #endif
 
     if (!d->baseImage.isNull ())
